# -*- coding: utf-8 -*-
from __future__ import unicode_literals
import logging
import os.path
from itertools import chain
from operator import attrgetter
from os.path import basename

from future.builtins import (int, map, open)
from django.contrib.auth.decorators import login_required
from django.contrib.sites.models import get_current_site
from django.core.exceptions import MultipleObjectsReturned
from django.core.servers.basehttp import FileWrapper
from django.http import HttpResponse, HttpResponseForbidden, Http404
from django.shortcuts import render
from django.utils import translation

import django_mobile_app_distribution.settings as app_dist_settings
from django_mobile_app_distribution.models import IosApp, AndroidApp, UserInfo

log = logging.getLogger(__name__)


@login_required
def index(request):
    try:
        # Activate client's language preference
        lang = request.user.userinfo.language
        translation.activate(lang)
    except UserInfo.DoesNotExist:
        pass

    ios_user_apps = IosApp.objects.filter(user_id__exact=request.user.id)
    android_user_apps = AndroidApp.objects.filter(user_id__exact=request.user.id)
    apps = list(chain(ios_user_apps, android_user_apps))

    ios_group_apps = IosApp.objects.filter(groups__in=request.user.groups.all())
    android_group_apps = AndroidApp.objects.filter(groups__in=request.user.groups.all())
    group_apps = list(chain(ios_group_apps, android_group_apps))
    for group_app in group_apps:
        if group_app not in apps:
            apps.append(group_app)

    apps.sort(key=attrgetter('updatedAt'), reverse=True)
    apps.sort(key=attrgetter('version'), reverse=True)
    apps.sort(key=attrgetter('operating_system'), reverse=True) # let iOS come first
    apps.sort(key=attrgetter('name'))

    return render(request, 'django_mobile_app_distribution/app_list.html', {
        'apps': apps,
        'ios_identifier': app_dist_settings.IOS,
        'site_url': get_current_site(request).domain
    })


@login_required
def send_apk(request, app_id):
    """
    Send a file through Django without loading the whole file into              
    memory at once. The FileWrapper will turn the file object into an           
    iterator for chunks of 8KB.                                                 
    """
    android_app = None
    try:
        android_app = AndroidApp.objects.get(pk=app_id)
    except (AndroidApp.DoesNotExist, MultipleObjectsReturned):
        return HttpResponse('App does not exist', status=404)

    authenticated = False
    if android_app.user:
        if android_app.user.id == request.user.id:
            authenticated = True

    if not authenticated:
        app_group_ids = android_app.groups.all().values_list('pk', flat=True)
        app_group_ids = list(map(int, app_group_ids))
        for user_group in request.user.groups.all():
            user_group_id = int(user_group.id)
            if user_group_id in app_group_ids:
                authenticated = True
                break

    if not authenticated:
        return HttpResponseForbidden('This is not your app')

    filename = os.path.join(
        app_dist_settings.MOBILE_APP_DISTRIBUTION_ANDROID_FILE_STORAGE_PATH,
        android_app.app_binary.name
    )
    response = HttpResponse(FileWrapper(open(filename, 'rb')))
    response['Content-Length'] = os.path.getsize(filename)
    response['Content-Type'] = app_dist_settings.MOBILE_APP_DISTRIBUTION_CONTENT_TYPES[android_app.operating_system]
    response['Content-Disposition'] = 'inline; filename=%s' % basename(filename)
    return response


def ios_app_plist(request, app_id):

    ios_app = None
    try:
        ios_app = IosApp.objects.get(pk=app_id)
    except (IosApp.DoesNotExist, MultipleObjectsReturned):
        raise Http404

    from . import settings as mad_settings
    plist = ''
    if ios_app.display_image and ios_app.full_size_image:
        plist = mad_settings.IOS_PLIST_BLUEPRINT_IOS9
        plist = plist.replace(mad_settings.PLIST_DISPLAY_IMAGE, ios_app.get_display_image_url())
        plist = plist.replace(mad_settings.PLIST_FULL_SIZE_IMAGE, ios_app.get_full_size_image_url())
    else:
        plist = mad_settings.IOS_PLIST_BLUEPRINT

    plist = plist.replace(mad_settings.PLIST_APP_URL, ios_app.get_binary_url())
    plist = plist.replace(mad_settings.PLIST_BUNDLE_IDENTIFIER, ios_app.bundle_identifier)
    plist = plist.replace(mad_settings.PLIST_BUNDLE_VERSION, ios_app.version)
    plist = plist.replace(mad_settings.PLIST_APP_TITLE, ios_app.name)

    return HttpResponse(
        plist,
        content_type=mad_settings.MOBILE_APP_DISTRIBUTION_CONTENT_TYPES[mad_settings.IOS_PLIST]
    )



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import django_mobile_app_distribution.models
import django.core.files.storage


class Migration(migrations.Migration):

    dependencies = [
        ('django_mobile_app_distribution', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='androidapp',
            options={'verbose_name': 'Android App', 'verbose_name_plural': 'Android Apps', 'ordering': ('name', 'operating_system', '-version', '-updatedAt')},
        ),
        migrations.AlterField(
            model_name='androidapp',
            name='app_binary',
            field=models.FileField(verbose_name='APK file', upload_to=django_mobile_app_distribution.models.normalize_android_filename, storage=django.core.files.storage.FileSystemStorage(location='/Users/moritz/Alp-Phone/Projects/mobile_app_distribution/ota_ad_hoc_management/ota_ad_hoc_management/android')),
        ),
        migrations.AlterField(
            model_name='androidapp',
            name='operating_system',
            field=models.CharField(verbose_name='Operating system', default='Android', max_length=50, choices=[('iOS', 'iOS'), ('Android', 'Android')], editable=False),
        ),
        migrations.AlterField(
            model_name='app',
            name='groups',
            field=models.ManyToManyField(verbose_name='Groups', default=None, blank=True, to='auth.Group', related_name='apps'),
        ),
        migrations.AlterField(
            model_name='app',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True),
        ),
        migrations.AlterField(
            model_name='iosapp',
            name='bundle_identifier',
            field=models.CharField(verbose_name='Bundle identifier', default='', max_length=200, help_text='e.g. org.example.app'),
        ),
        migrations.AlterField(
            model_name='iosapp',
            name='operating_system',
            field=models.CharField(verbose_name='Operating system', default='iOS', max_length=50, choices=[('iOS', 'iOS'), ('Android', 'Android')], editable=False),
        ),
        migrations.AlterField(
            model_name='userinfo',
            name='language',
            field=models.CharField(default='en', max_length=20, choices=[('en', 'English'), ('de', 'Deutsch')]),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
import logging

from django.forms import ModelForm, ValidationError
from django.utils.translation import ugettext_lazy as _
from django_mobile_app_distribution.models import IosApp, AndroidApp

logger = logging.getLogger(__name__)


class AppAdminForm(ModelForm):
    def clean(self):
        cleaned_data = super(AppAdminForm, self).clean()

        user = cleaned_data.get('user')
        groups = cleaned_data.get('groups')

        if not user and not groups:
            raise ValidationError(_('Please assign a user or group to the app.'))

        return cleaned_data


class iOSAppAdminForm(AppAdminForm):
    class Meta:
        model = IosApp
        fields = '__all__'

    def clean(self):
        cleaned_data = super(AppAdminForm, self).clean()

        display_image = cleaned_data.get('display_image')
        full_size_image = cleaned_data.get('full_size_image')

        if (display_image or full_size_image) and not (display_image and full_size_image):
            error = ValidationError(_('Please provide a display and a full size image.'))
            self.add_error('display_image', error)
            self.add_error('full_size_image', error)

        return cleaned_data


class AndroidAppAdminForm(AppAdminForm):
    class Meta:
        model = AndroidApp
        fields = '__all__'



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
import logging

from django.contrib import admin, messages
from django.contrib.auth.models import User
from django.contrib.sites.models import get_current_site
from django.core.mail import EmailMultiAlternatives
from django.core.urlresolvers import reverse
from django.template.loader import render_to_string
from django.utils import translation
from django.utils.translation import ugettext_lazy as _, ungettext_lazy

from django_mobile_app_distribution import settings as _settings
from django_mobile_app_distribution.models import IosApp, AndroidApp
from django_mobile_app_distribution.forms import iOSAppAdminForm, AndroidAppAdminForm
from django_mobile_app_distribution.models import UserInfo


logger = logging.getLogger(__name__)


class UserInfoAdmin(admin.ModelAdmin):
    model = UserInfo
    list_display = ['user', 'language']
    list_editable = ['language']
    search_fields = ['user__username']


class NotifiableModelAdmin(admin.ModelAdmin):
    actions = ['notify_client']
    search_fields = ['name', 'user__username', 'groups__name', 'comment']

    def notify_client(self, request, queryset):
        for app in queryset.all():
            recipients = []

            if app.user and app.user.email:
                recipients.append(app.user.email)

            if app.groups.count() > 0:
                group_users = User.objects.filter(groups__in=app.groups.all())
                for user in group_users:
                    if user.email and user.email not in recipients:
                        recipients.append(user.email)

            if recipients:
                recipient_count = len(recipients)
                if request.user.email and request.user.email not in recipients:
                    recipients.append(request.user.email)

                try:
                    # Try and send email in client's preferred language
                    # This doesn't make much sense for apps distributed to groups
                    # hence the catch all except clause
                    lang = app.user.userinfo.language
                    translation.activate(lang)
                except Exception:
                    pass

                domain = get_current_site(request).domain
                index_url = reverse('django_mobile_app_distribution_index')
                data = {
                    'email_link_color_hex': _settings.EMAIL_LINK_COLOR_HEX,
                    'app_name': app.name,
                    'app_version': app.version,
                    'os': app.operating_system,
                    'download_url': '/'.join(s.strip('/') for s in (domain, index_url))
                }

                email = EmailMultiAlternatives()
                email.bcc = recipients
                email.subject = _('Version %(app_version)s of %(app_name)s for %(os)s is available for download') % data
                email.body = _(
                    'Version %(app_version)s of %(app_name)s for %(os)s is available for download.\n'
                    'Please visit %(download_url)s to install the app.'
                ) % data
                email.attach_alternative(
                    render_to_string('django_mobile_app_distribution/email_notification.html', data),
                    'text/html'
                )

                # Reset to system language
                translation.deactivate()

                email.send(fail_silently=False)
                messages.add_message(
                    request,
                    messages.INFO, ungettext_lazy(
                        '%(recipient_count)s user was notified of %(app_name)s %(app_version)s availability.',
                        '%(recipient_count)s users were notified of %(app_name)s %(app_version)s availability.',
                        recipient_count) % {
                        'recipient_count' : recipient_count,
                        'app_name' : app.name,
                        'app_version': app.version
                        },
                    fail_silently=True)
            else:
                messages.add_message(
                    request, messages.ERROR, _('Nobody was notified by email because nobody\'s email address is set.'),
                    fail_silently=True
                )
    notify_client.short_description = _('Notify clients of app availability')

    def user_display_name(self, instance):
        if instance.user:
            return instance.user.username
        else:
            return ''
    user_display_name.short_description = _('User')
    user_display_name.admin_order_field = 'user'

    def groups_display_name(self, instance):
        if instance.groups.count() > 0:
            return ", ".join(str(group) for group in instance.groups.all())
        else:
            return ''
    groups_display_name.short_description = _('Groups')


class IosAppAdmin(NotifiableModelAdmin):
    form = iOSAppAdminForm
    list_display = ('name', 'user_display_name', 'groups_display_name', 'version', 'comment', 'updatedAt')
    filter_horizontal = ['groups']

    fieldsets = (
        (_('App info'), {
            'fields': ('user', 'groups', 'name', 'version', 'bundle_identifier', 'app_binary', 'comment')
        }),
        (_('Provide these deploy on iOS 9'), {
            'fields': ('display_image', 'full_size_image')
        }),
    )


class AndroidAppAdmin(NotifiableModelAdmin):
    form = AndroidAppAdminForm
    list_display = ('name', 'user_display_name', 'groups_display_name', 'version', 'comment', 'updatedAt')
    filter_horizontal = ['groups']

    fieldsets = (
        (_('App info'), {
            'fields': ('user', 'groups', 'name', 'version', 'app_binary', 'comment')
        }),
    )


admin.site.register(IosApp, IosAppAdmin)
admin.site.register(AndroidApp, AndroidAppAdmin)
admin.site.register(UserInfo, UserInfoAdmin)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import django.core.files.storage
import django_mobile_app_distribution.models


class Migration(migrations.Migration):

    dependencies = [
        ('django_mobile_app_distribution', '0003_auto_20150807_1250'),
    ]

    operations = [
        migrations.AlterField(
            model_name='androidapp',
            name='app_binary',
            field=models.FileField(upload_to=django_mobile_app_distribution.models.normalize_android_filename, storage=django.core.files.storage.FileSystemStorage(location='/Users/moritz/Alp-Phone/Projects/mobile_app_distribution/migrations_generator/migrations_generator/android'), verbose_name='APK file'),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import django_mobile_app_distribution.models


class Migration(migrations.Migration):

    dependencies = [
        ('django_mobile_app_distribution', '0002_auto_20150730_1357'),
    ]

    operations = [
        migrations.AddField(
            model_name='iosapp',
            name='display_image',
            field=models.ImageField(default='', help_text='57x57 PNG', upload_to=django_mobile_app_distribution.models.normalize_image_filename, blank=True),
        ),
        migrations.AddField(
            model_name='iosapp',
            name='full_size_image',
            field=models.ImageField(default='', help_text='512x512 PNG', upload_to=django_mobile_app_distribution.models.normalize_image_filename, blank=True),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from django.conf.urls import patterns, url

urlpatterns = patterns('',
                       url(
                           r'^$',
                           'django_mobile_app_distribution.views.index',
                           name='django_mobile_app_distribution_index'
                       ),
                       url(
                           r'^apk/(?P<app_id>\d{1,10})$',
                           'django_mobile_app_distribution.views.send_apk',
                           name='django_mobile_app_distribution_send_apk'
                       ),
                       url(
                           r'^plist/(?P<app_id>\d{1,10})\.plist$',
                           'django_mobile_app_distribution.views.ios_app_plist',
                           name='django_mobile_app_distribution_ios_app_plist'
                       ),
                       )



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

class MobileAppDistributionConfigurationException(Exception):
    """A misconfiguration within the Django Mobile App Distribution settings is causing invalid states"""
    pass



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
import logging
import os
from unicodedata import normalize

from django.core.urlresolvers import reverse
from django.contrib.auth.models import User, Group
from django.contrib.sites.models import Site
from django.core.files.storage import FileSystemStorage
from django.db import models
from django.db.models.signals import post_save
from django.utils import six
from django.utils.encoding import python_2_unicode_compatible, force_text
from django.utils.translation import ugettext_lazy as _

import django_mobile_app_distribution.settings as app_dist_settings
from django_mobile_app_distribution.exceptions import MobileAppDistributionConfigurationException

if six.PY2:
    from urlparse import urljoin
else:
    from urllib.parse import urljoin


log = logging.getLogger(__name__)


_MISSING_SITE_MESSAGE = "The site framework's domain name is used to generate the plist and binary links.  " \
                        "Please configure your current site properly. Also make sure that the SITE_ID in your " \
                        "settings file matches the primary key of your current site."

def normalize_filename(dirname, filename):
    dirname = force_text(dirname)
    filename = force_text(normalize('NFKD', filename).encode('ascii', 'ignore'))
    return force_text(os.path.join(dirname, filename))


def normalize_ios_filename(instance, filename):
    return normalize_filename(app_dist_settings.MOBILE_APP_DISTRIBUTION_IOS_UPLOAD_TO_DIRECTORY_NAME, filename)


def normalize_android_filename(instance, filename):
    return normalize_filename(app_dist_settings.MOBILE_APP_DISTRIBUTION_ANDROID_UPLOAD_TO_DIRECTORY_NAME, filename)

def normalize_image_filename(instance, filename):
    return normalize_filename(app_dist_settings.MOBILE_APP_DISTRIBUTION_APP_ICON_DIRECTORY_NAME, filename)


@python_2_unicode_compatible
class UserInfo(models.Model):
    user = models.OneToOneField(User)
    language = models.CharField(max_length=20, choices=app_dist_settings.LANGUAGES, default=app_dist_settings.ENGLISH)

    def __str__(self):
        return self.user.username

    class Meta:
        verbose_name = _('Extended user info')
        verbose_name_plural = _('Extended user info')


@python_2_unicode_compatible
class App(models.Model):
    user = models.ForeignKey(User, blank=True, null=True, default=None, related_name='apps', verbose_name=_('User'))
    groups = models.ManyToManyField(
        Group,
        blank=True,
        related_name='apps',
        default=None,
        verbose_name=_('Groups')
    )
    name = models.CharField(max_length=200, verbose_name=_('App name'))
    comment = models.CharField(max_length=200, verbose_name=_('Comment'), blank=True, null=True)
    version = models.CharField(max_length=200, verbose_name=_('Bundle version'))
    updatedAt = models.DateTimeField(auto_now=True, editable=False)
    createdAt = models.DateTimeField(auto_now_add=True, editable=False)

    def __str__(self):
        return self.name


class IosApp(App):

    operating_system = models.CharField(
        max_length=50,
        choices=app_dist_settings.OS_CHOICES,
        default=app_dist_settings.IOS,
        verbose_name=_('Operating system'),
        editable=False
    )
    app_binary = models.FileField(upload_to=normalize_ios_filename, verbose_name=_('IPA file'))
    bundle_identifier = models.CharField(
        max_length=200,
        verbose_name=_('Bundle identifier'),
        default='',
        help_text=_('e.g. org.example.app')
    )
    display_image = models.ImageField(
        upload_to=normalize_image_filename,
        default='',
        help_text='57x57 PNG',
        blank=True
    )
    full_size_image = models.ImageField(
        upload_to=normalize_image_filename,
        default='',
        help_text='512x512 PNG',
        blank=True
    )

    def get_binary_url(self):
        if not self.app_binary:
            return None
        Site.objects.clear_cache()
        try:
            Site.objects.get_current()
        except Exception:
            raise MobileAppDistributionConfigurationException(_MISSING_SITE_MESSAGE)

        return urljoin(Site.objects.get_current().domain, self.app_binary.url)

    def get_plist_url(self):
        Site.objects.clear_cache()
        current_site = None
        try:
            current_site = Site.objects.get_current()
        except Exception:
            raise MobileAppDistributionConfigurationException(_MISSING_SITE_MESSAGE)
        return urljoin(
            current_site.domain,
            reverse('django_mobile_app_distribution_ios_app_plist', kwargs={'app_id': self.pk})
        )

    def get_display_image_url(self):
        Site.objects.clear_cache()
        current_site = None
        try:
            current_site = Site.objects.get_current()
        except Exception:
            raise MobileAppDistributionConfigurationException(_MISSING_SITE_MESSAGE)

        return urljoin(Site.objects.get_current().domain, self.display_image.url)

    def get_full_size_image_url(self):
        Site.objects.clear_cache()
        current_site = None
        try:
            current_site = Site.objects.get_current()
        except Exception:
            raise MobileAppDistributionConfigurationException(_MISSING_SITE_MESSAGE)

        return urljoin(Site.objects.get_current().domain, self.full_size_image.url)

    class Meta:
        verbose_name = _('iOS App')
        verbose_name_plural = _('iOS Apps')
        ordering = ('name', 'operating_system', '-version', '-updatedAt',)


fs = FileSystemStorage(location=app_dist_settings.MOBILE_APP_DISTRIBUTION_ANDROID_FILE_STORAGE_PATH)


class AndroidApp(App):
    operating_system = models.CharField(
        max_length=50,
        choices=app_dist_settings.OS_CHOICES,
        default=app_dist_settings.ANDROID,
        verbose_name=_('Operating system'),
        editable=False
    )
    app_binary = models.FileField(upload_to=normalize_android_filename, verbose_name=_('APK file'), storage=fs)

    class Meta:
        verbose_name = _('Android App')
        verbose_name_plural = _('Android Apps')
        ordering = ( 'name', 'operating_system', '-version', '-updatedAt',)


def create_user_info(sender, instance, created, **kwargs):
    try:
        instance.userinfo
    except Exception:
        try:
            UserInfo.objects.create(user=instance)
        except Exception:
            # happens when creating a superuser when syncdb is run before the tables are installed
            pass

post_save.connect(create_user_info, sender=User)



import os
from setuptools import setup, find_packages

README = open(os.path.join(os.path.dirname(__file__), 'README.md')).read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-mobile-app-distribution',
    version='0.3.10',
    packages=find_packages(),
    include_package_data=True,
    license='MIT License', 
    description='A Django app that adds iOS and Android app upload functionality to the Django admin interface.  Provides a mobile optimized HTML fronted for clients to download Ad Hoc mobile applications using their iOS or Android devices.',
    long_description=README,
    url='https://github.com/Proper-Job/django-mobile-app-distribution',
    author='Moritz Pfeiffer',
    author_email='moritz.pfeiffer@alp-phone.ch',
    zip_safe=False,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    install_requires=['future', 'Pillow']
)


# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from os.path import join
from django.conf import settings


def get(key, default):
    return getattr(settings, key, default)

IOS = 'iOS'
IOS_PLIST = 'iOS Plist'
ANDROID = 'Android'
OS_CHOICES = (
    (IOS, 'iOS'),
    (ANDROID, 'Android'),
)

MOBILE_APP_DISTRIBUTION_CONTENT_TYPES = {
    IOS: 'application/octet-stream ipa',
    IOS_PLIST: 'text/xml plist',
    ANDROID: 'application/vnd.android.package-archive'
}

MOBILE_APP_DISTRIBUTION_IOS_UPLOAD_TO_DIRECTORY_NAME = get(
    'MOBILE_APP_DISTRIBUTION_IOS_UPLOAD_TO_DIRECTORY_NAME',
    'ios_apps'
)
MOBILE_APP_DISTRIBUTION_ANDROID_UPLOAD_TO_DIRECTORY_NAME = get(
    'MOBILE_APP_DISTRIBUTION_ANDROID_UPLOAD_TO_DIRECTORY_NAME',
    'android_apps'
)
MOBILE_APP_DISTRIBUTION_APP_ICON_DIRECTORY_NAME = get(
    'MOBILE_APP_DISTRIBUTION_ANDROID_UPLOAD_TO_DIRECTORY_NAME',
    'app_icons'
)
MOBILE_APP_DISTRIBUTION_ANDROID_FILE_STORAGE_PATH = join(
    settings.BASE_PATH,
    get('MOBILE_APP_DISTRIBUTION_ANDROID_FILE_STORAGE_PATH', 'android')
)

EMAIL_LINK_COLOR_HEX = '#267d87'

ENGLISH = 'en'
GERMAN = 'de'

LANGUAGES = (
    (ENGLISH, 'English'),
    (GERMAN, 'Deutsch'),
)

PLIST_APP_URL = '__app_url__'
PLIST_BUNDLE_IDENTIFIER = '__bundle_identifier__'
PLIST_BUNDLE_VERSION = '__bundle_version__'
PLIST_APP_TITLE = '__app_title__'
PLIST_DISPLAY_IMAGE = '__display_image'
PLIST_FULL_SIZE_IMAGE = '__full_size_image'

IOS_PLIST_BLUEPRINT = """<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
    <key>items</key>
    <array>
        <dict>
            <key>assets</key>
            <array>
                <dict>
                    <key>kind</key>
                    <string>software-package</string>
                    <key>url</key>
                    <string>{url}</string>
                </dict>
            </array>
            <key>metadata</key>
            <dict>
                <key>bundle-identifier</key>
                <string>{bundle_id}-ios8</string>
                <key>bundle-version</key>
                <string>{bundle_version}</string>
                <key>kind</key>
                <string>software</string>
                <key>title</key>
                <string>{app_title}</string>
            </dict>
        </dict>
    </array>
</dict>
</plist>
""".format(
    url=PLIST_APP_URL,
    bundle_id=PLIST_BUNDLE_IDENTIFIER,
    bundle_version=PLIST_BUNDLE_VERSION,
    app_title=PLIST_APP_TITLE
)

# Docs: http://help.apple.com/deployment/ios/#/apda0e3426d7
IOS_PLIST_BLUEPRINT_IOS9 = """<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
    <key>items</key>
    <array>
        <dict>
            <key>assets</key>
            <array>
                <dict>
                    <key>kind</key>
                    <string>software-package</string>
                    <key>url</key>
                    <string>{url}</string>
                </dict>
                <dict>
                    <key>kind</key>
                    <string>display-image</string>
                    <key>url</key>
                    <string>{display_image}</string>
                </dict>
                <dict>
                    <key>kind</key>
                    <string>full-size-image</string>
                    <key>url</key>
                    <string>{full_size_image}</string>
                </dict>
            </array>
            <key>metadata</key>
            <dict>
                <key>bundle-identifier</key>
                <string>{bundle_id}</string>
                <key>bundle-version</key>
                <string>{bundle_version}</string>
                <key>kind</key>
                <string>software</string>
                <key>title</key>
                <string>{app_title}</string>
            </dict>
        </dict>
    </array>
</dict>
</plist>
""".format(
    url=PLIST_APP_URL,
    bundle_id=PLIST_BUNDLE_IDENTIFIER,
    bundle_version=PLIST_BUNDLE_VERSION,
    app_title=PLIST_APP_TITLE,
    display_image=PLIST_DISPLAY_IMAGE,
    full_size_image=PLIST_FULL_SIZE_IMAGE
)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import django_mobile_app_distribution.models
from django.conf import settings
import django.core.files.storage


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='App',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=200, verbose_name='App name')),
                ('comment', models.CharField(max_length=200, null=True, verbose_name='Comment', blank=True)),
                ('version', models.CharField(max_length=200, verbose_name='Bundle version')),
                ('updatedAt', models.DateTimeField(auto_now=True, auto_now_add=True)),
                ('createdAt', models.DateTimeField(auto_now_add=True)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='AndroidApp',
            fields=[
                ('app_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='django_mobile_app_distribution.App')),
                ('operating_system', models.CharField(default=b'Android', verbose_name='Operating System', max_length=50, editable=False, choices=[(b'iOS', b'iOS'), (b'Android', b'Android')])),
                ('app_binary', models.FileField(upload_to=django_mobile_app_distribution.models.normalize_android_filename, storage=django.core.files.storage.FileSystemStorage(location=b'/Users/moritz/Alp-Phone/Projects/mobile_app_distribution/migrations_generator/migrations_generator/android'), verbose_name='APK file')),
            ],
            options={
                'ordering': ('name', 'operating_system', '-version', '-updatedAt'),
                'verbose_name': 'Android app',
                'verbose_name_plural': 'Android apps',
            },
            bases=('django_mobile_app_distribution.app',),
        ),
        migrations.CreateModel(
            name='IosApp',
            fields=[
                ('app_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='django_mobile_app_distribution.App')),
                ('operating_system', models.CharField(default=b'iOS', verbose_name='Operating System', max_length=50, editable=False, choices=[(b'iOS', b'iOS'), (b'Android', b'Android')])),
                ('app_binary', models.FileField(upload_to=django_mobile_app_distribution.models.normalize_ios_filename, verbose_name='IPA file')),
                ('bundle_identifier', models.CharField(default=b'', help_text='e.g. org.example.app', max_length=200, verbose_name='Bundle identifier')),
            ],
            options={
                'ordering': ('name', 'operating_system', '-version', '-updatedAt'),
                'verbose_name': 'iOS App',
                'verbose_name_plural': 'iOS Apps',
            },
            bases=('django_mobile_app_distribution.app',),
        ),
        migrations.CreateModel(
            name='UserInfo',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('language', models.CharField(default=b'en', max_length=20, choices=[(b'en', b'English'), (b'de', b'Deutsch')])),
                ('user', models.OneToOneField(to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'Extended user info',
                'verbose_name_plural': 'Extended user info',
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='app',
            name='groups',
            field=models.ManyToManyField(related_name='apps', default=None, to='auth.Group', blank=True, null=True, verbose_name='Groups'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='app',
            name='user',
            field=models.ForeignKey(related_name='apps', default=None, blank=True, to=settings.AUTH_USER_MODEL, null=True, verbose_name='User'),
            preserve_default=True,
        ),
    ]
